##parameters=mode, datastructure
# $Id: widget_my_prepare_validate.py 29531 2005-11-15 11:07:47Z fguillaume $
"""
XXX add docstring
"""

datamodel = datastructure.getDataModel()

widget_id = context.getWidgetId()
field_id = context.fields[0]

if mode == 'prepare':
    datastructure.set(widget_id, datamodel[field_id])
    return

if mode == 'validate':
    value = datastructure.get(widget_id, '')
    if not value.startswith('my'):
        datastructure.setError(widget_id,
                               "Argh error, doit commencer par 'my'")
        ok = 0
    else:
        datamodel.set(field_id, value)
        ok = 1
    return ok
